VERSION 5.00
Begin VB.Form Form1 
   Caption         =   "TrueVision Example 2"
   ClientHeight    =   4485
   ClientLeft      =   5085
   ClientTop       =   1770
   ClientWidth     =   6030
   LinkTopic       =   "Form1"
   ScaleHeight     =   4485
   ScaleWidth      =   6030
End
Attribute VB_Name = "Form1"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
'-------------------------------------------------------------
' TrueVision Tutorial 2 : Simple mesh
'------------------------------------------------------------
' TrueVision supports 3DS, X, Milkshape3D, DXE & TVO format
' for the meshes. But you can create your own mesh with
' the TrueVision standard methods.
' This tutorial will give you the bases for creating
' simple meshes like Room with TrueVision8
'-------------------------------------------------------------
'Look at the Form_Load for the next part of the tutorial
'

' General declarations :
Public TV As New TrueVision8
Public Scene As New Scene8
Public TexFactory As New TextureFactory8
Public Inp As New InputEngine8
Public Camera As New Camera8

'Our mesh will be stored in a Mesh8 class.
'Note that Mesh objects must be created by
'the Scene8 class
Private Room As Mesh8



Private Sub Form_Load()
    '1. Show the form in that the scene will be rendered.
    Form1.Show
    TV.DisplayFPS = True
    
    '2. Initialize the engine in windowed mode.
    '   Note that you have to use the Hwnd of the desired form or picturebox
    TV.Init3DWindowedMode Form1.hWnd
    
    '2b. Defines the data directory. Usually it's the application path
    TV.SetSearchDirectory App.Path
    
    '3. Create the room
    '3a : Create the mesh from the scene object
    Set Room = Scene.CreateMeshBuilder("Room")
    
    '3b : Add the walls to the room using the Mesh8.AddWall method
    '     We will set the texture later...
    Room.AddWall Nothing, -10, -10, 10, -10, 20
    Room.AddWall Nothing, 10, -10, 10, 10, 20
    Room.AddWall Nothing, 10, 10, -10, 10, 20
    Room.AddWall Nothing, -10, 10, -10, -10, 20
    
    '3c : Add the floor and the ceiling using the Mesh8.AddFloor method
    Room.AddFloor Nothing, -10, -10, 10, 10, 0
    Room.AddFloor Nothing, -10, -10, 10, 10, 20
    
    
    '3d : Load a brick texture. Note that TrueVision can load
    '     BMP, JPG, DDS, PNG, GIF picture files.
    TexFactory.LoadTexture "brick1.bmp", "BrickTexture"
    
    '3e : Apply the texture to the room
    Room.SetTexture GetTex("BrickTexture")
    
    '4 : Set the camera startpos
    Camera.SetCameraPosition 0, 10, 0
    Camera.SetCameraLookAt 0, 10, 1
    
    'The main game loop :
    Do
      'Clear the screen. You must do this before rendering anything on the screen.
      TV.Clear
      
      'Call the room rendering method
      Scene.RenderAllMeshes
      
      'Render everything on the screen
      TV.RenderToScreen
      
      'Move the scene according to the keyboard presses.
      If Inp.IsKeyPressed(TV_KEY_UP) = True Then Camera.MoveForward 20
      If Inp.IsKeyPressed(TV_KEY_DOWN) = True Then Camera.MoveForward -20
      If Inp.IsKeyPressed(TV_KEY_RIGHT) = True Then Camera.RotateCameraY -60
      If Inp.IsKeyPressed(TV_KEY_LEFT) = True Then Camera.RotateCameraY 60
      
    'Check the Escape Key that ends up the tutorial
    Loop Until Inp.IsKeyPressed(TV_KEY_ESCAPE) = True
    
    'Don't forget to shut down the engine
    Set TV = Nothing
    End
End Sub


